[−][src]Trait sp_core::Hasher
Trait describing an object that can hash a slice of bytes. Used to abstract
other types over the hashing algorithm. Defines a single hash method and an
Out associated type with the necessary bounds.
Associated Types
type Out: MaybeDebug + Clone + PartialEq<Self::Out> + Eq + AsRef<[u8]> + AsMut<[u8]> + Default + Send + Copy + Sync + Hash[−]
The output type of the Hasher
type StdHasher: Default + Send + Sync + Hasher[−]
What to use to build HashMaps with this Hasher.
Associated Constants
Required methods
fn hash(x: &[u8]) -> Self::Out[−]
Compute the hash of the provided slice of bytes returning the Out type of the Hasher.
Implementors
impl Hasher for Blake2Hasher[src][+]
impl Hasher for KeccakHasher[src][+]
impl Hasher for BlakeTwo256
impl Hasher for BlakeTwo256impl Hasher for Keccak256
impl Hasher for Keccak256